#Install the packages you need
install.packages(c("tidyverse", "ggplot2"))

#Load packages
library(tidyverse)
library(ggplot2)

#Transform the data into a time series and see how mortality has developed in Poland
data <- ts(DATA$VARIABLE)
plot(data)

#Split the TIME column into year and week data
DATA <- DATA %>%
  separate(TIME, into = c("Year", "Week"), sep = "-W")

#Check the data structure
str(DATA)

#Swap data type
DATA$VARIABLE <- as.numeric(DATA$VARIABLE)
DATA$VARIABLE <- as.numeric(DATA$VARIABLE)

#Check the data structure again ;)
str(DATA)

#Select data for the period 2000-2019 which is the basis for calculating expected mortality
Expected <- DATA %>%
  filter(YEAR >= 2000 & YEAT <= 2019)

#Calculate the average mortality rate each week
Baseline <- Expected %>%
  group_by(Week) %>%
  summarise(Ex_PL = mean(Poland, na.rm = TRUE))

#Generate a chart showing the development of expected mortality in Poland
ggplot(Baseline, aes(x = Week, y = Ex_PL)) +
  geom_line() +
  geom_smooth(method = "loess", se = FALSE, color = "red") +  # Add a smoothing line
  labs(title = "Weekly expected mortality in Poland",
       x = "Week",
       y = "Crude death rate") +
  theme_minimal()

#Visualization, for the Y axis starting from 0
ggplot(Baseline, aes(x = Week, y = Ex_PL)) +
  geom_line() +
  geom_smooth(method = "loess", se = FALSE, color = "red") +  # Add a smoothing line
  labs(title = "Weekly expected mortality in Poland",
       x = "Week",
       y = "Crude death rate") +
  scale_y_continuous(limits = c(0, max(Baseline$Ex_PL)), expand = c(0, 0)) +
  theme_minimal()

#Append Expected Mortality to the input dataset
DATA <- DATA %>%
  left_join(Baseline, by = "Week")

#Calculate the difference between actual and expected mortality
DATA <- DATA %>%
  mutate(ExcessM = Poland - Ex_PL)

#Show data from 2020
DATA <- as.data.frame(DATA)
pandemic <- DATA %>%
  filter(YEAR >= 2020)

#Visualization of excess mortality during the pandemic
pandemic_ts <- ts(pandemic[, c("EX_PL", "ExcessM")])
pandemic_df <- data.frame(Week = time(pandemic_ts), as.data.frame(pandemic_ts))
ggplot(pandemic_df, aes(x = Week, y = Ex_PL, group = 1)) +
  geom_line(aes(color = "Ex_PL"), linetype = "dashed") +
  geom_line(aes(x = Week, y = ExcessM, color = "ExcessM"), linetype = "solid") +
  labs(title = "Weekly excess mortality in Poland",
       y = "Crude death rate",
       color = "Legend") +
  theme_minimal()
